Empty collection reports 1 document

Tuesday, 26 October 2010 · 5 messages · last reply 27 Oct 2010
JV
Jan Vlčinský26 Oct 2010 14:28 #
Hi Collection with none and one document inside reports the same count of documents: 1
Quoted text · 1 line
> create db Test3
Database 'Test3' created in 119.19 ms.
Quoted text · 1 line
> xquery count(collection('Test3'))
1 Query executed in 0.43 ms.
Quoted text · 1 line
> xquery for $doc in collection("Test3") return base-uri($doc)
file:/D:/opt/BaseX/Test3 Query executed in 0.74 ms.
Quoted text · 1 line
> xquery /
Query executed in 0.33 ms.
Quoted text · 1 line
> add as xml.xml <root/>
Path 'xml.xml' added in 3.67 ms.
Quoted text · 1 line
> xquery /
<root/> Query executed in 1.1 ms.
Quoted text · 1 line
> xquery count(collection('Test3'))
1 Query executed in 0.54 ms.
Quoted text · 1 line
>
With best regards Jan PS: If I should fill it to some bug tracking tool, just let me know where I can find it. Sourceforge?
-- *Jan Vlčinský* Slunečnicová 338/3, 734 01 Karviná Ráj, Czech Republic tel: +420-597 602 024; mob: +420-608 979 040 skype: janvlcinsky; GoogleTalk: jan.vlcinsky at gmail.com
MS
Michael Seiferle26 Oct 2010 15:26 #
Hi Jan, currently creating a DB inserts a (dummy):document-node() into the DB; to allow:
Quoted text · Jan Vlčinský · 2 lines
> create db test2 > insert node <xml /> as first into .
which does not add a document but adds a node to before created document-node(). We put this on our TODO list, trying to find a solution. We are using a private Redmine internally, so I am sorry I can not give you an URL. But reporting via the Mailinglist is just fine. You might also use Sourceforge [1] Kind regards Michael [1] http://sourceforge.net/tracker/?group_id=192179&atid=940354
Quoted text · Jan Vlčinský · 32 lines
Am 26.10.2010 um 14:28 schrieb Jan Vlčinský: > Hi > Collection with none and one document inside reports the same count of documents: 1 > > > create db Test3 > Database 'Test3' created in 119.19 ms. > > xquery count(collection('Test3')) > 1 > Query executed in 0.43 ms. > > xquery for $doc in collection("Test3") return base-uri($doc) > file:/D:/opt/BaseX/Test3 > Query executed in 0.74 ms. > > xquery / > > Query executed in 0.33 ms. > > add as xml.xml <root/> > Path 'xml.xml' added in 3.67 ms. > > xquery / > <root/> > Query executed in 1.1 ms. > > xquery count(collection('Test3')) > 1 > Query executed in 0.54 ms. > > > > With best regards > > Jan > > PS: If I should fill it to some bug tracking tool, just let me know where I can find it. Sourceforge? > -- >
MS
Michael Seiferle27 Oct 2010 12:31 #
Hi Jan, the latest repository version contains a fix that addresses your problem: Check it out from: http://www.inf.uni-konstanz.de/dbis/basex/community If you need a precompiled jar let me know. Kind regards Michael
Quoted text · Michael Seiferle · 59 lines
Am 26.10.2010 um 15:26 schrieb Michael Seiferle: > Hi Jan, > > currently creating a DB inserts a (dummy):document-node() into the DB; > to allow: >> create db test2 >> insert node <xml /> as first into . > which does not add a document but adds a node to before created document-node(). > > We put this on our TODO list, trying to find a solution. > > We are using a private Redmine internally, so I am sorry I can not give you an URL. > But reporting via the Mailinglist is just fine. You might also use Sourceforge [1] > > > Kind regards > Michael > > [1] http://sourceforge.net/tracker/?group_id=192179&atid=940354 > > > Am 26.10.2010 um 14:28 schrieb Jan Vlčinský: > >> Hi >> Collection with none and one document inside reports the same count of documents: 1 >> >> > create db Test3 >> Database 'Test3' created in 119.19 ms. >> > xquery count(collection('Test3')) >> 1 >> Query executed in 0.43 ms. >> > xquery for $doc in collection("Test3") return base-uri($doc) >> file:/D:/opt/BaseX/Test3 >> Query executed in 0.74 ms. >> > xquery / >> >> Query executed in 0.33 ms. >> > add as xml.xml <root/> >> Path 'xml.xml' added in 3.67 ms. >> > xquery / >> <root/> >> Query executed in 1.1 ms. >> > xquery count(collection('Test3')) >> 1 >> Query executed in 0.54 ms. >> > >> >> With best regards >> >> Jan >> >> PS: If I should fill it to some bug tracking tool, just let me know where I can find it. Sourceforge? >> -- >> > > _______________________________________________ > BaseX-Talk mailing list > BaseX-Talk at mailman.uni-konstanz.de > https://mailman.uni-konstanz.de/mailman/listinfo/basex-talk
JV
Jan Vlčinský27 Oct 2010 13:34 #
Michale Precompiled jar would safe me 40 to 90 minutes of experimenting. I have all the SDK, maven, svn installed, but I am not daily user. Jan
Quoted text · Michael Seiferle · 79 lines
On Wed, Oct 27, 2010 at 12:31 PM, Michael Seiferle < michael.seiferle at uni-konstanz.de> wrote: > Hi Jan, > > the latest repository version contains a fix that addresses your problem: > Check it out from: http://www.inf.uni-konstanz.de/dbis/basex/community > > If you need a precompiled jar let me know. > > Kind regards > Michael > > Am 26.10.2010 um 15:26 schrieb Michael Seiferle: > > > Hi Jan, > > > > currently creating a DB inserts a (dummy):document-node() into the DB; > > to allow: > >> create db test2 > >> insert node <xml /> as first into . > > which does not add a document but adds a node to before created > document-node(). > > > > We put this on our TODO list, trying to find a solution. > > > > We are using a private Redmine internally, so I am sorry I can not give > you an URL. > > But reporting via the Mailinglist is just fine. You might also use > Sourceforge [1] > > > > > > Kind regards > > Michael > > > > [1] http://sourceforge.net/tracker/?group_id=192179&atid=940354 > > > > > > Am 26.10.2010 um 14:28 schrieb Jan Vlčinský: > > > >> Hi > >> Collection with none and one document inside reports the same count of > documents: 1 > >> > >> > create db Test3 > >> Database 'Test3' created in 119.19 ms. > >> > xquery count(collection('Test3')) > >> 1 > >> Query executed in 0.43 ms. > >> > xquery for $doc in collection("Test3") return base-uri($doc) > >> file:/D:/opt/BaseX/Test3 > >> Query executed in 0.74 ms. > >> > xquery / > >> > >> Query executed in 0.33 ms. > >> > add as xml.xml <root/> > >> Path 'xml.xml' added in 3.67 ms. > >> > xquery / > >> <root/> > >> Query executed in 1.1 ms. > >> > xquery count(collection('Test3')) > >> 1 > >> Query executed in 0.54 ms. > >> > > >> > >> With best regards > >> > >> Jan > >> > >> PS: If I should fill it to some bug tracking tool, just let me know > where I can find it. Sourceforge? > >> -- > >> > > > > _______________________________________________ > > BaseX-Talk mailing list > > BaseX-Talk at mailman.uni-konstanz.de > > https://mailman.uni-konstanz.de/mailman/listinfo/basex-talk > >
-- *Jan Vlčinský* Slunečnicová 338/3, 734 01 Karviná Ráj, Czech Republic tel: +420-597 602 024; mob: +420-608 979 040 skype: janvlcinsky; GoogleTalk: jan.vlcinsky at gmail.com
MS
Michael Seiferle27 Oct 2010 15:39 #
Hi Jan, whoops sorry I kind of overlooked your answer... I'll send you the jar in a minute! Kind regards Michael
Quoted text · Jan Vlčinský · 86 lines
Am 27.10.2010 um 13:34 schrieb Jan Vlčinský: > Michale > Precompiled jar would safe me 40 to 90 minutes of experimenting. I have all the SDK, maven, svn installed, but I am not daily user. > Jan > > On Wed, Oct 27, 2010 at 12:31 PM, Michael Seiferle <michael.seiferle at uni-konstanz.de> wrote: > Hi Jan, > > the latest repository version contains a fix that addresses your problem: > Check it out from: http://www.inf.uni-konstanz.de/dbis/basex/community > > If you need a precompiled jar let me know. > > Kind regards > Michael > > Am 26.10.2010 um 15:26 schrieb Michael Seiferle: > > > Hi Jan, > > > > currently creating a DB inserts a (dummy):document-node() into the DB; > > to allow: > >> create db test2 > >> insert node <xml /> as first into . > > which does not add a document but adds a node to before created document-node(). > > > > We put this on our TODO list, trying to find a solution. > > > > We are using a private Redmine internally, so I am sorry I can not give you an URL. > > But reporting via the Mailinglist is just fine. You might also use Sourceforge [1] > > > > > > Kind regards > > Michael > > > > [1] http://sourceforge.net/tracker/?group_id=192179&atid=940354 > > > > > > Am 26.10.2010 um 14:28 schrieb Jan Vlčinský: > > > >> Hi > >> Collection with none and one document inside reports the same count of documents: 1 > >> > >> > create db Test3 > >> Database 'Test3' created in 119.19 ms. > >> > xquery count(collection('Test3')) > >> 1 > >> Query executed in 0.43 ms. > >> > xquery for $doc in collection("Test3") return base-uri($doc) > >> file:/D:/opt/BaseX/Test3 > >> Query executed in 0.74 ms. > >> > xquery / > >> > >> Query executed in 0.33 ms. > >> > add as xml.xml <root/> > >> Path 'xml.xml' added in 3.67 ms. > >> > xquery / > >> <root/> > >> Query executed in 1.1 ms. > >> > xquery count(collection('Test3')) > >> 1 > >> Query executed in 0.54 ms. > >> > > >> > >> With best regards > >> > >> Jan > >> > >> PS: If I should fill it to some bug tracking tool, just let me know where I can find it. Sourceforge? > >> -- > >> > > > > _______________________________________________ > > BaseX-Talk mailing list > > BaseX-Talk at mailman.uni-konstanz.de > > https://mailman.uni-konstanz.de/mailman/listinfo/basex-talk > > > > > -- > Jan Vlčinský > Slunečnicová 338/3, 734 01 Karviná Ráj, Czech Republic > tel: +420-597 602 024; mob: +420-608 979 040 > skype: janvlcinsky; GoogleTalk: jan.vlcinsky at gmail.com >

⚡Generated with XQuery